==> ezpublish-4.0.0.tgz: ezpublish/extension/ezodf/translations/jpn-JP/translation.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>extension/ezodf</name>
    <message>
        <source>Import</source>
        <translation>インポート</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>エクスポート</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>リプレイス</translation>
    </message>
    <message>
        <source>Choose document placement</source>
        <translation>ドキュメントの配置を選択してください</translation>
    </message>
    <message>
        <source>Upload file</source>
        <translation>ファイルをアップロード</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <source>Export Object</source>
        <translation>エクスポート</translation>
    </message>
    <message>
        <source>OpenOffice.org import</source>
        <translation>OpenOffice.orgインポート</translation>
    </message>
    <message>
        <source>OpenOffice.org export</source>
        <translation>OpenOffice.orgエクスポート</translation>
    </message>
    <message>
        <source>Export eZ publish content to OpenOffice.org</source>
        <translation>eZ PublsihのコンテントをOpenOffice.orgへエクスポート</translation>
    </message>
    <message>
        <source>Here you can export any eZ publish content object to an OpenOffice.org Writer document format.</source>
        <translation>eZ Publish のコンテントをOpenOffice.org Writer へエクスポートします。</translation>
    </message>
    <message>
        <source>Document is now imported</source>
        <translation>ドキュメントはインポートされました</translation>
    </message>
    <message>
        <source>The object was imported as: %class_name</source>
        <translation>オブジェクトは%class_nameとしてインポートされました</translation>
    </message>
    <message>
        <source>Document imported as</source>
        <translation>インポートされたドキュメント:</translation>
    </message>
    <message>
        <source>The images are placed in the media and can be re-used.</source>
        <translation>画像はメディアへ保存されました。再利用が可能です。</translation>
    </message>
    <message>
        <source>Import another document</source>
        <translation>他のドキュメントをインポート</translation>
    </message>
    <message>
        <source>Import OpenOffice.org document</source>
        <translation>OpenOffice.orgドキュメントをインポート</translation>
    </message>
    <message>
        <source>Replace document</source>
        <translation>ドキュメントをリプレイス</translation>
    </message>
    <message>
        <source>Import to</source>
        <translation>インポート先</translation>
    </message>
    <message>
        <source>You can import OpenOffice.org Writer documents directly into eZ publish from this page. You are
asked where to place the document and eZ publish does the rest. The document is converted into
the appropriate class during the import, you get a notice about this after the import is done.
Images are placed in the media library so you can re-use them in other articles.</source>
        <translation>OpenOffice.org WriterドキュメントをeZ Publishへインポートします。ドキュメントの配置先を指定して下さい。
インポート完了語に通知が表示されます。
画像はメディアライブラリに保存されますので、後に再利用が可能です。</translation>
    </message>
</context>
<context>
    <name>extension/ezodf/browse</name>
    <message>
        <source>Choose document placement</source>
        <translation>ドキュメントの配置を選択してください</translation>
    </message>
    <message>
        <source>Please choose the placement for the OpenOffice.org object.

    Select the placements and click the %buttonname button.
    Using the recent and bookmark items for quick placement is also possible.
    Click on placement names to change the browse listing.</source>
        <translation>OpenOffice.orgドキュメントの配置先を選択して下さい。
配置先を選択し、%buttonnameをクリックして下さい。
ブックマークやアイテムの履歴を利用することも可能です。
ブラウズリストを移動するには名前をクリックして下さい。</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>選択</translation>
    </message>
</context>
<context>
    <name>extension/ezodf/export/error</name>
    <message>
        <source>Destination file format not supported</source>
        <translation>フォーマットがサポートされていません</translation>
    </message>
    <message>
        <source>PDF conversion failed</source>
        <translation>PDFのコンバージョンに失敗しました</translation>
    </message>
    <message>
        <source>Word conversion failed</source>
        <translation>Wordのコンバージョンに失敗しました</translation>
    </message>
    <message>
        <source>Unable to fetch node, or no read access</source>
        <translation>ノードが見つからないか、アクセスがありません。</translation>
    </message>
    <message>
        <source>Unable to open file %1 on server side</source>
        <translation>ファイル%1を開けません。</translation>
    </message>
</context>
<context>
    <name>extension/ezodf/import/error</name>
    <message>
        <source>File extension or type is not allowed.</source>
        <translation>ファイルエクステンション又はタイプが無効です。</translation>
    </message>
    <message>
        <source>Could not parse XML.</source>
        <translation>XMLを分析できませんでした</translation>
    </message>
    <message>
        <source>Can not open socket. Please check if extension/ezodf/daemon.php is running.</source>
        <translation>ソケットを開けません。extension/ezodf/daemon.phpが起動しているか確認して下さい。</translation>
    </message>
    <message>
        <source>Can not convert the given document.</source>
        <translation>このドキュメントを変換できません。</translation>
    </message>
    <message>
        <source>Unable to call daemon. Fork can not create child process.</source>
        <translation>デーモンへアクセスできません。フォークがチャイルドプロセスを作成できません。</translation>
    </message>
    <message>
        <source>Daemon reported error.</source>
        <translation>デーモンがエラーを起こしています。</translation>
    </message>
    <message>
        <source>Unknown node.</source>
        <translation>不明なノード</translation>
    </message>
    <message>
        <source>Access denied.</source>
        <translation>アクセスが拒否されました</translation>
    </message>
    <message>
        <source>Error during import.</source>
        <translation>インポート中にエラーが起きました</translation>
    </message>
    <message>
        <source>Unknown content class specified in odf.ini:</source>
        <translation>不明なコンテントクラスodf.ini:</translation>
    </message>
    <message>
        <source>Unknown error.</source>
        <translation>不明なエラー</translation>
    </message>
    <message>
        <source>Filetype: </source>
        <translation>ファイルタイプ:</translation>
    </message>
    <message>
        <source>Unable to fetch node with id  </source>
        <translation>ノードが見つかりません</translation>
    </message>
    <message>
        <source>Folder for images could not be created, access denied.</source>
        <translation>アクセスが拒否されました。画像フォルダーが作成できませんでした。</translation>
    </message>
    <message>
        <source>Document is not suported.</source>
        <translation>ドキュメントはサポートされていません。</translation>
    </message>
    <message>
        <source>Cannot import. File not found. Already imported?</source>
        <translation>インポートできません。ファイルが見つかりませんでした。既にインポートしていますか?</translation>
    </message>
    <message>
        <source>Cannot import document, supplied placement nodeID is not valid.</source>
        <translation>ドキュメントをインポートできません。ノードIDが無効です。</translation>
    </message>
    <message>
        <source>Cannot store uploaded file, cannot import.</source>
        <translation>アップロードしたファイルを保存できません。</translation>
    </message>
</context>
<context>
    <name>extension/ezodf/popupmenu</name>
    <message>
        <source>Export OpenOffice.org</source>
        <translation>OpenOffice.orgをエクスポート</translation>
    </message>
    <message>
        <source>Export PDF</source>
        <translation>PDFをエクスポート</translation>
    </message>
    <message>
        <source>Export Word</source>
        <translation>Wordをエクスポート</translation>
    </message>
    <message>
        <source>Import OpenOffice.org</source>
        <translation>OpenOffice.orgをインポート</translation>
    </message>
    <message>
        <source>Replace OpenOffice.org</source>
        <translation>OpenOffice.orgをリプレイス</translation>
    </message>
</context>
</TS>

==> ezpublish-4.1.3.tgz: ezpublish/extension/ezodf/translations/jpn-JP/translation.ts <==
<!DOCTYPE TS><TS>
<defaultcodec></defaultcodec>
<context>
    <name>extension/ezodf</name>
    <message>
        <source>Upload file</source>
        <translation>ファイルをアップロード</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <source>Export Object</source>
        <translation>エクスポート</translation>
    </message>
    <message>
        <source>OpenOffice.org import</source>
        <translation>OpenOffice.orgインポート</translation>
    </message>
    <message>
        <source>OpenOffice.org export</source>
        <translation>OpenOffice.orgエクスポート</translation>
    </message>
    <message>
        <source>Document is now imported</source>
        <translation>ドキュメントはインポートされました</translation>
    </message>
    <message>
        <source>The object was imported as: %class_name</source>
        <translation>オブジェクトは%class_nameとしてインポートされました</translation>
    </message>
    <message>
        <source>Document imported as</source>
        <translation>インポートされたドキュメント:</translation>
    </message>
    <message>
        <source>Import another document</source>
        <translation>他のドキュメントをインポート</translation>
    </message>
    <message>
        <source>Import OpenOffice.org document</source>
        <translation>OpenOffice.orgドキュメントをインポート</translation>
    </message>
    <message>
        <source>Replace document</source>
        <translation>ドキュメントをリプレイス</translation>
    </message>
    <message>
        <source>Import to</source>
        <translation>インポート先: </translation>
    </message>
    <message>
        <source>Export eZ Publish content to OpenOffice.org</source>
        <translation>eZ PublishのコンテンツをOpenOffice.orgへエクスポート</translation>
    </message>
    <message>
        <source>Here you can export any eZ Publish content object to an OpenOffice.org Writer document format.</source>
        <translation>eZ Publish のコンテンツをOpenOffice.org Writer へエクスポートします。</translation>
    </message>
    <message>
        <source>The images are placed in the media library and can be re-used.</source>
        <translation>画像はメディアリソースへ保存されました。再利用が可能です。</translation>
    </message>
    <message>
        <source>You can import OpenOffice.org Writer documents directly into eZ Publish from this page. You are
asked where to place the document and eZ Publish does the rest. The document is converted into
the appropriate class during the import, you get a notice about this after the import is done.
Images are placed in the media library so you can re-use them in other articles.</source>
        <translation>OpenOffice.org WriterドキュメントをeZ Publishへインポートします。ドキュメントの配置先を指定して下さい。
インポート完了後に通知が表示されます。画像はメディアリソースに保存されますので、後に再利用が可能です。</translation>
    </message>
</context>
<context>
    <name>extension/ezodf/browse</name>
    <message>
        <source>Choose document placement</source>
        <translation>ドキュメントの配置先を選択してください</translation>
    </message>
    <message>
        <source>Please choose the placement for the OpenOffice.org object.

    Select the placements and click the %buttonname button.
    Using the recent and bookmark items for quick placement is also possible.
    Click on placement names to change the browse listing.</source>
        <translation>OpenOffice.orgドキュメントの配置先を選択して下さい。
配置先を選択し、%buttonnameをクリックして下さい。
ブックマークやアイテムの履歴を利用することも可能です。
ブラウズリストを移動するには名前をクリックして下さい。</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>選択</translation>
    </message>
</context>
<context>
    <name>extension/ezodf/export/error</name>
    <message>
        <source>Destination file format not supported</source>
        <translation>フォーマットがサポートされていません</translation>
    </message>
    <message>
        <source>PDF conversion failed</source>
        <translation>PDFのコンバージョンに失敗しました</translation>
    </message>
    <message>
        <source>Word conversion failed</source>
        <translation>Wordのコンバージョンに失敗しました</translation>
    </message>
    <message>
        <source>Unable to fetch node, or no read access</source>
        <translation>ノードが見つからないか、アクセスがありません。</translation>
    </message>
    <message>
        <source>Unable to open file %1 on server side</source>
        <translation>ファイル%1を開けません。</translation>
    </message>
</context>
<context>
    <name>extension/ezodf/import/error</name>
    <message>
        <source>File extension or type is not allowed.</source>
        <translation>ファイルエクステンション又はタイプが無効です。</translation>
    </message>
    <message>
        <source>Could not parse XML.</source>
        <translation>XMLを分析できませんでした</translation>
    </message>
    <message>
        <source>Can not open socket. Please check if extension/ezodf/daemon.php is running.</source>
        <translation>ソケットを開けません。extension/ezodf/daemon.phpが起動しているか確認して下さい。</translation>
    </message>
    <message>
        <source>Can not convert the given document.</source>
        <translation>このドキュメントを変換できません。</translation>
    </message>
    <message>
        <source>Unable to call daemon. Fork can not create child process.</source>
        <translation>デーモンへアクセスできません。フォークがチャイルドプロセスを作成できません。</translation>
    </message>
    <message>
        <source>Daemon reported error.</source>
        <translation>デーモンがエラーを起こしています。</translation>
    </message>
    <message>
        <source>Unknown node.</source>
        <translation>不明なノード</translation>
    </message>
    <message>
        <source>Access denied.</source>
        <translation>アクセスが拒否されました</translation>
    </message>
    <message>
        <source>Error during import.</source>
        <translation>インポート中にエラーが起きました</translation>
    </message>
    <message>
        <source>Unknown content class specified in odf.ini:</source>
        <translation>odf.iniに不明なコンテンツクラスが見つかりました:</translation>
    </message>
    <message>
        <source>Unknown error.</source>
        <translation>不明なエラー</translation>
    </message>
    <message>
        <source>Filetype: </source>
        <translation>ファイルタイプ:</translation>
    </message>
    <message>
        <source>Folder for images could not be created, access denied.</source>
        <translation>アクセスが拒否されました。画像フォルダーが作成できませんでした。</translation>
    </message>
    <message>
        <source>Cannot import. File not found. Already imported?</source>
        <translation>インポートできません。ファイルが見つかりませんでした。既にインポートしていますか?</translation>
    </message>
    <message>
        <source>Cannot import document, supplied placement nodeID is not valid.</source>
        <translation>ドキュメントをインポートできません。ノードIDが無効です。</translation>
    </message>
    <message>
        <source>Cannot store uploaded file, cannot import.</source>
        <translation>アップロードしたファイルを保存できません。</translation>
    </message>
    <message>
        <source>Unable to fetch node with id </source>
        <translation>ノードが見つかりません</translation>
    </message>
    <message>
        <source>Document is not supported.</source>
        <translation>ドキュメントはサポートされていません。</translation>
    </message>
</context>
<context>
    <name>extension/ezodf/popupmenu</name>
    <message>
        <source>Export PDF</source>
        <translation>PDFをエクスポート</translation>
    </message>
    <message>
        <source>Export Word</source>
        <translation>Wordをエクスポート</translation>
    </message>
    <message>
        <source>OpenOffice.org</source>
        <translation>OpenOffice.org</translation>
    </message>
    <message>
        <source>Export OpenOffice</source>
        <translation>OpenOfficeファイルにエクスポートする</translation>
    </message>
    <message>
        <source>Import OpenOffice</source>
        <translation>OpenOfficeファイルをインポートする</translation>
    </message>
    <message>
        <source>Replace OpenOffice</source>
        <translation>OpenOfficeファイルをリプレイスする</translation>
    </message>
</context>
</TS>
